read_bus_public_key

Function read_bus_public_key 

pub async fn read_bus_public_key() -> Result<[u8; 32]>
Read the bus server’s public key from the runtime directory.

Connecting daemons call this before initiating the Noise IK handshake (the “K” in IK — responder’s static key is Known to the initiator).

Errors

Returns an error if the file does not exist or is not exactly 32 bytes.